# Gestione errori globale
$ErrorActionPreference = "Stop"

# Funzione per controllare se PowerShell è in modalità amministratore
function Test-Administrator {
    $user = [Security.Principal.WindowsIdentity]::GetCurrent()
    $principal = New-Object Security.Principal.WindowsPrincipal($user)
    return $principal.IsInRole([Security.Principal.WindowsBuiltInRole]::Administrator)
}

# Funzione per controllare SMB
function Check-SMB {
    try {
        Write-Host "`nControllo stato SMB 1.0/CIFS..." -ForegroundColor Yellow
        
        # Controlla tramite registro di sistema
        $smb1Present = Get-ItemProperty -Path "HKLM:\SYSTEM\CurrentControlSet\Services\LanmanServer\Parameters" -Name "SMB1" -ErrorAction SilentlyContinue
        
        if ($smb1Present) {
            Write-Host "SMB1 Stato nel registro: " -NoNewline
            if ($smb1Present.SMB1 -eq 1) {
                Write-Host "ATTIVO" -ForegroundColor Green
            } else {
                Write-Host "NON ATTIVO" -ForegroundColor Red
            }
        } else {
            Write-Host "SMB1 non trovato nel registro" -ForegroundColor Yellow
        }

        # Controlla anche le funzionalità Windows
        $features = @(
            "SMB1Protocol-Client",
            "SMB1Protocol-Server",
            "SMB1Protocol"
        )
        
        foreach ($feature in $features) {
            $status = Get-WindowsOptionalFeature -Online -FeatureName $feature -ErrorAction SilentlyContinue
            Write-Host "$feature : " -NoNewline
            if ($status.State -eq "Enabled") {
                Write-Host "ATTIVO" -ForegroundColor Green
            } else {
                Write-Host "NON ATTIVO" -ForegroundColor Red
            }
        }
    } catch {
        Write-Host "Errore nel controllo SMB: $_" -ForegroundColor Red
        return $false
    }
    return $true
}

# Funzione per attivare SMB
function Enable-SMB {
    try {
        Write-Host "Attivazione SMB 1.0/CIFS..." -ForegroundColor Yellow

        # Primo metodo: Registro di sistema
        Write-Host "Configurazione registro di sistema..." -ForegroundColor Yellow
        Set-ItemProperty -Path "HKLM:\SYSTEM\CurrentControlSet\Services\LanmanServer\Parameters" -Name "SMB1" -Value 1 -Type DWord -Force

        # Secondo metodo: PowerShell cmdlets
        Write-Host "Attivazione funzionalità Windows..." -ForegroundColor Yellow
        
        # Abilita SMB1 tramite PowerShell
        Enable-WindowsOptionalFeature -Online -FeatureName "SMB1Protocol" -All -NoRestart

        # Riavvia il servizio Server
        Write-Host "Riavvio servizio Server..." -ForegroundColor Yellow
        Restart-Service -Name "LanmanServer" -Force

        Write-Host "Attivazione SMB completata" -ForegroundColor Green
        
        # Verifica finale
        Check-SMB
    } catch {
        Write-Host "Errore nell'attivazione SMB: $_" -ForegroundColor Red
        Write-Host "Tentativo alternativo di attivazione..." -ForegroundColor Yellow
        
        try {
            # Metodo alternativo usando dism
            Start-Process -FilePath "dism.exe" -ArgumentList "/online /enable-feature /featurename:SMB1Protocol" -Wait -NoNewWindow
            Write-Host "Attivazione completata con metodo alternativo" -ForegroundColor Green
        } catch {
            Write-Host "Anche il metodo alternativo ha fallito: $_" -ForegroundColor Red
        }
    }
}

# Funzione per controllare il servizio FDResPub
function Check-FDResPub {
    try {
        Write-Host "`nControllo servizio 'Pubblicazione risorse per individuazione'..." -ForegroundColor Yellow
        $service = Get-Service -Name "FDResPub" -ErrorAction SilentlyContinue
        
        if ($service) {
            Write-Host "Stato: " -NoNewline
            if ($service.Status -eq "Running") {
                Write-Host "ATTIVO" -ForegroundColor Green
            } else {
                Write-Host "NON ATTIVO" -ForegroundColor Red
            }
            
            Write-Host "Tipo avvio: " -NoNewline
            if ($service.StartType -eq "Automatic") {
                Write-Host "AUTOMATICO" -ForegroundColor Green
            } else {
                Write-Host $service.StartType -ForegroundColor Red
            }
        } else {
            Write-Host "Servizio non trovato" -ForegroundColor Red
            return $false
        }
    } catch {
        Write-Host "Errore nel controllo del servizio: $_" -ForegroundColor Red
        return $false
    }
    return $true
}

# Funzione per configurare il servizio FDResPub
function Enable-FDResPub {
    try {
        $service = Get-Service -Name "FDResPub"
        Set-Service -Name "FDResPub" -StartupType Automatic
        Start-Service -Name "FDResPub"
        Write-Host "Servizio configurato correttamente" -ForegroundColor Green
    } catch {
        Write-Host "Errore nella configurazione del servizio: $_" -ForegroundColor Red
    }
}

# Menu principale
function Show-Menu {
    do {
        Clear-Host
        Write-Host "=== MENU CONFIGURAZIONE SERVIZI ===" -ForegroundColor Cyan
        Write-Host "1. Controlla stato SMB" -ForegroundColor White
        Write-Host "2. Attiva SMB" -ForegroundColor White
        Write-Host "3. Controlla stato Servizio Pubblicazione" -ForegroundColor White
        Write-Host "4. Attiva Servizio Pubblicazione" -ForegroundColor White
        Write-Host "5. Esci" -ForegroundColor White
        
        Write-Host "`nScegli un'opzione (1-5): " -ForegroundColor Yellow -NoNewline
        $choice = Read-Host
        
        switch ($choice) {
            "1" { Check-SMB; pause }
            "2" { Enable-SMB; pause }
            "3" { Check-FDResPub; pause }
            "4" { Enable-FDResPub; pause }
            "5" { return }
            default { 
                Write-Host "Opzione non valida" -ForegroundColor Red
                pause
            }
        }
    } while ($true)
}

# Punto di ingresso principale
if (-not (Test-Administrator)) {
    Write-Host "Questo script richiede privilegi di amministratore." -ForegroundColor Red
    Write-Host "Riavvia PowerShell come amministratore." -ForegroundColor Yellow
    pause
    exit
}

try {
    Show-Menu
} catch {
    Write-Host "Errore generale: $_" -ForegroundColor Red
    pause
}